#
# spec file for package python-aiosmtplib
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-aiosmtplib
Version:        4.0.1
Release:        1.1
Summary:        Python asyncio SMTP client
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/cole/aiosmtplib
Source:         https://files.pythonhosted.org/packages/source/a/aiosmtplib/aiosmtplib-%{version}.tar.gz
BuildRequires:  %{python_module exceptiongroup}
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module trustme}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Suggests:       python-aiosmtpd
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module aiosmtpd}
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module pytest-asyncio}
# /SECTION
%python_subpackages

%description
Python asyncio SMTP client.

%prep
%autosetup -p1 -n aiosmtplib-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest -rs -k "not test_live and not test_tls"

%files %{python_files}
%doc README.rst docs/*.rst
%license LICENSE.txt
%{python_sitelib}/aiosmtplib
%{python_sitelib}/aiosmtplib-%{version}.dist-info

%changelog
* Tue May 20 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 4.0.1
  * Bugfix: Always clear the connect lock on connection lost,
    allowing client reconnect
* Fri Apr  4 2025 Nico Krapp <nico.krapp@suse.com>
- Update to 4.0.0
  * BREAKING: Drop Python 3.8 support
  * Bugfix: Run socket.getfqdn in thread to avoid blocking event loop if local_hostname not provided (thanks @Raidzin)
  * Bugfix: Clear connect lock on connection lost, allowing client reconnect
  * Bugfix: Allow socket connections to use TLS by providing hostname and use_tls=True
* Fri Nov  8 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 3.0.2
  * Bugfix: Type of "send" is partially unknown with pyright
  * Bugfix: Fix asyncio deadlock trying to reconnect after error
  * Change: Switched from Poetry to build/hatch/twine for packaging.
- Skip test_live and test_tls tests when running testsuite
- Switch package to modern Python Stack on SLE-15
  * Use Python 3.11 on SLE-15 by default
  * Drop support for older Python versions
- Switch build system from setuptools to pyproject.toml
  * Add python-pip and python-wheel to BuildRequires
  * Replace %%python_build with %%pyproject_wheel
  * Replace %%python_install with %%pyproject_install
- Limit Python files matched in %%files section
* Tue Nov 14 2023 Dirk Müller <dmueller@suse.com>
- update to 3.0.1:
  * Bugfix: 'Future exception was never retrieved' warning in
    SMTPProtocol after successful connection close and garbage
    collection.
  * Cleanup: Updated FlowControlMixin logic from stdlib
    are keyword only.
  * **BREAKING**: Passing ``source_address`` as a string argument
    is now an error. ``source_address``  takes a (addr, port)
    tuple that is used as the ``local_addr`` param of
    ``asyncio.create_connection``, allowing for binding
    to a specific IP. The ``local_hostname`` argument takes the
    value to be sent to the server with the EHLO/HELO message
    (which is what ``source_address`` was used for prior to 2.0).
  * Change: don't use timeout value passed to ``connect``
    everywhere, only for the initial connection
  * Change: removed unnecessary connection lost callback
  * Change: revised handling for 'Future exception was never
    retrieved' warnings in protocol
* Tue Jun 20 2023 Dirk Müller <dmueller@suse.com>
- update to 2.0.2:
  * Bugfix: don't send extra EHLO/HELO before QUIT
  * Change: added SMTPConnectionResponseError for invalid
    response on connect only
* Fri Feb 10 2023 Dirk Müller <dmueller@suse.com>
- update to 2.0.1:
  * Bugfix: "tests" and "docs" in the sdist should be includes,
    not packages, so that they do not get put in site-packages.
* Thu Nov 10 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to v2.0.0
  * BREAKING: Drop Python 3.5 and 3.6 support.
  * BREAKING: On connect, if the server supports STARTTLS, automatically try to upgrade the connection.
    STARTTLS after connect can be turned on or off explicitly by passing start_tls=True or start_tls=False respectively.
  * BREAKING: Remove deprecated loop keyword argument for the SMTP class.
  * Change: The source_address argument now takes a (addr, port) tuple that is passed as the local_addr param to asyncio.create_connection,
    allowing for binding to a specific IP. The new local_hostname argument that takes the value to be sent to the server with the EHLO/HELO message.
    This behaviour more closely matches smtplib.
  * In order to not break existing usage, passing a string instead of a tuple to source_address will give a DeprecationWarning,
    and use the value as it if had been passed for local_hostname.
  * Thanks @rafaelrds and @davidmcnabnz for raising and contributing work on this issue.
  * Bugfix: the mail_options and rcpt_options arguments to the send coroutine no longer cause errors
  * Cleanup: Refactored SMTP parent classes to remove complex inheritance structure.
  * Cleanup: Switched to asyncio.run for sync client methods.
  * Cleanup: Don't use private email.message.Message policy attribute (instead, set an appropriate policy based on message class)
- Update to v1.1.7
  * Security: Fix a possible injection vulnerability (a variant of https://consensys.net/diligence/vulnerabilities/python-smtplib-multiple-crlf-injection/)
  * Note that in order to exploit this vulnerability in aiosmtplib, the attacker would need control of the hostname or source_address parameters.
    Thanks Sam Sanoop @ Snyk for bringing this to my attention.
  * Bugfix: include CHANGLOG in sdist release
  * Type hints: fix type hints for async context exit (credit @JelleZijlstra)
* Sat Jan 15 2022 Dirk Müller <dmueller@suse.com>
- update to 1.1.6:
  * update auth other than login
- remove failing_smtpd_tests.patch: not needed
* Fri May  7 2021 Matej Cepl <mcepl@suse.com>
- Add failing_smtpd_tests.patch to fix failing tests
  (gh#cole/aiosmtplib#171).
* Fri Apr 30 2021 Matej Cepl <mcepl@suse.com>
- Update to 1.1.5:
  - Bugfix: avoid raising asyncio.CancelledError on connection lost
  - Bugfix: allow UTF-8 chars in usernames and password strings
  - Feature: allow bytes type args for login usernames and passwords
- Switch off failing tests because of gh#cole/aiosmtplib#171.
* Sun Nov 29 2020 John Vandenberg <jayvdb@gmail.com>
- Add docs/*.rst to %%doc
- Remove a test skip that has been resolved upstream
- Update to v1.1.4
  * Bugfix: parsing comma separated addresses in to header
- from v1.1.3
  * Feature: add pause and resume writing methods to SMTPProcotol,
    via asyncio.streams.FlowControlMixin
  * Bugfix: allow an empty sender
  * Cleanup: more useful error message when login called without TLS
* Mon Mar 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Remove docs/tests folders that were not supposed to be installed
* Thu Jan 16 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 1.1.2
  * Fix handling of sending legacy email API (Message) objects.
  * Fix SMTPNotSupported error with UTF8 sender/recipient names
    on servers that don’t support SMTPUTF8.
* Tue Sep 17 2019 Tomáš Chvátal <tchvatal@suse.com>
- Format with spec-cleaner
* Tue Sep 17 2019 John Vandenberg <jayvdb@gmail.com>
- Skip two online tests, and one failing test on i586
* Wed Sep 11 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.1.0
